##########
Quickstart
##########

The best way to get started is to download our tutorial. Our tutorial contains Jupyter notebooks and example models that illustrate how to use the BPTK_Py framework to build models in Python System Dynamics, agent-based modeling and how to transpile models in XMILE format.

You can download the tutorial from our `website <https://www.transentis.com/products/business-prototyping-toolkit/>`_. The tutorial comes in a ZIP file. Unzip the package at a temporary location and move the contents of the package into the root folder of your virtual environment.

The objective of the tutorial is to illustrate how to use the BPTK_PY framework, not to introduce System Dynamics modeling or Agent-based modeling in general.

We illustrate the framework using a simple project management model and the Bass Diffusion model:

* *Simple Project Management Model*. This model is an illustration of `Parkinson's law <https://en.wikipedia.org/wiki/Parkinson%27s_law>`_, which states that work expands so as to fill the time available for its completion.
* *Bass Diffusion Model*. This model is an implementation of the `Bass Diffusion Model <https://en.wikipedia.org/wiki/Bass_diffusion_model>`_ originally created by `Frank Bass <https://en.wikipedia.org/wiki/Frank_Bass>`_ that describes the process of how new products get adopted in a population. The Bass model has been widely used in forecasting, especially new products' sales forecasting and technology forecasting.

You can learn more about these models on our blog:

* `Step-by-step introduction to System Dynamics <https://www.transentis.com/step-by-step-tutorials/introduction-to-system-dynamics/>`_ using the simple project management model.
* Introduction to the `Bass Diffusion Model <https://www.transentis.com/causal-loop-diagramming/>`_.

Here is an overview of the documents contained in this tutorial:

* *Writing Computational Essays Using Simulation Models.* Introduction to using simulation models built with ®Stella in Jupyter Notebooks using the BPTK_PY framework.
* *A Simple Python Library for System Dynamics.* Introduction to using the BPTK_PY framework to built SD models directly in Juptyer Notebooks.
* *Introduction to Agent Based Simulation Modeling with BPTK_PY.* This notebook illustrates how to create an agent-based implementation of a simple project management model.
* *An Agent-based Implementation of the Bass Diffusion Model* A simple notebook to run an agent-based implementation of the Bass Diffusion model.
* *In Depth Discussion Of The Business Prototyping Toolkit for Python.* A discussion of how the BPTK_PY framework works and some of the advanced API features not covered in the other notebooks.

